Empty

Struct Empty 

pub struct Empty(/* private fields */);
A parser that always succeeds without consuming any input.

Implementations

Source

impl Empty

pub const fn new() -> Self

Creates a parser that always succeeds without consuming any input.